@@ -13,10 +13,12 @@ test_that("is{Multi,Single}objective works fine", {
 		name = "Multi-objective function",
 		fn = function(x) c(x^2, exp(x)),
 		n.objectives = 2L,
-		par.set = makeNumericParamSet(id = "x", len = 1L)
+		par.set = makeNumericParamSet(id = "x", len = 1L),
+    ref.point = c(11, 11)
 	)
 
 	expect_true(isMultiobjective(fn))
 	expect_false(isSingleobjective(fn))
 	expect_equal(getNumberOfObjectives(fn), 2L)
-})
\ No newline at end of file
+  expect_equal(getRefPoint(fn), c(11, 11))
+})
